Dev
===

This directory is a place for Gammapy developers to put stuff that is useful
for reproducibility or maintenance, such as scripts to produce reference results for unit tests.

Documentation should go in ``docs/dev``.
